@@ -3,7 +3,7 @@
 set -e
 
 # Bash 4.3 - 5.0 because of arbitrary need to pick a single standard.
-if ! [[ "${BASH_VERSINFO[0]}.${BASH_VERSINFO[1]}" =~ (4\.[^1-2]|5\.0)(\.\d+)? ]]; then
+if ! [[ "${BASH_VERSINFO[0]}.${BASH_VERSINFO[1]}" =~ (4\.[^1-2]|5\.[0-2])(\.\d+)? ]]; then
   echo "this script requires bash 4.3, 4.4, or 5.0" >&2
   exit 1
 fi
